@@ -1,3 +1,4 @@
+from mhd_model.model import MHD_MODEL_V0_1_LEGACY_PROFILE_NAME
 from mhd_model.model.v0_1.dataset.validation.profile.base import (
     EmbeddedRefValidation,
     RelationshipValidation,
@@ -16,23 +17,19 @@ from mhd_model.model.v0_1.rules.managed_cv_terms import (
     COMMON_CHARACTERISTIC_DEFINITIONS,
     COMMON_MEASUREMENT_TYPES,
     COMMON_OMICS_TYPES,
-    COMMON_PARAMETER_DEFINITIONS,
-    COMMON_PROTOCOL_PARAMETERS,
     COMMON_PROTOCOLS,
-    COMMON_STUDY_FACTOR_DEFINITIONS,
     COMMON_TECHNOLOGY_TYPES,
 )
 from mhd_model.shared.model import CvTerm
 from mhd_model.shared.validation.definitions import (
     AllowAnyCvTerm,
     AllowedChildrenCvTerms,
-    AllowedCvList,
     AllowedCvTerms,
     CvTermPlaceholder,
     ParentCvTerm,
 )
 
-MHD_LEGACY_PROFILE_V0_1 = MhDatasetValidation()
+MHD_LEGACY_PROFILE_V0_1 = MhDatasetValidation(schema=MHD_MODEL_V0_1_LEGACY_PROFILE_NAME)
 
 MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
     NodeValidation(
@@ -101,7 +98,6 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 target="descriptor",
                 min=0,
                 min_for_each_source=0,
-                max_for_each_source=0,
             ),
             RelationshipValidation(
                 description="A link to a study that the assay was conducted as part of it "
@@ -150,6 +146,15 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 min=0,
                 min_for_each_source=0,
             ),
+            RelationshipValidation(
+                source="characteristic-definition",
+                relationship_name="has-type",
+                reverse_relationship_name="type-of",
+                target="characteristic-type",
+                min=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="characteristic-definition",
                 relationship_name="used-in",
@@ -228,6 +233,15 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
             ),
         ],
         relationships=[
+            RelationshipValidation(
+                source="factor-definition",
+                relationship_name="has-type",
+                reverse_relationship_name="type-of",
+                target="factor-type",
+                min=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="factor-definition",
                 relationship_name="has-instance",
@@ -242,7 +256,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="has-factor-definition",
                 target="study",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -260,11 +274,6 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 node_property_name="name",
                 contraints=PropertyConstraint(required=True, min_length=2),
             ),
-            NodePropertyValidation(
-                node_type="metadata-file",
-                node_property_name="extension",
-                contraints=PropertyConstraint(required=True, min_length=2),
-            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -288,7 +297,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 relationship_name="describes",
                 reverse_relationship_name="has-metadata-file",
                 target="study",
-                min=0,
+                min=1,
                 min_for_each_source=1,
                 max_for_each_source=1,
             ),
@@ -370,7 +379,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
             NodePropertyValidation(
                 node_type="organization",
                 node_property_name="name",
-                contraints=PropertyConstraint(required=True, min_length=10),
+                contraints=PropertyConstraint(required=True, min_length=1),
             ),
         ],
         relationships=[
@@ -449,6 +458,15 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 min=0,
                 min_for_each_source=0,
             ),
+            RelationshipValidation(
+                source="parameter-definition",
+                relationship_name="has-type",
+                reverse_relationship_name="type-of",
+                target="parameter-type",
+                min=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="parameter-definition",
                 relationship_name="defined-in",
@@ -743,8 +761,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="has-raw-data-file",
                 target="study",
                 min=0,
-                min_for_each_source=0,
-                max_for_each_source=0,
+                min_for_each_source=1,
             ),
             RelationshipValidation(
                 source="raw-data-file",
@@ -860,21 +877,31 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 min=0,
                 min_for_each_source=0,
             ),
+            RelationshipValidation(
+                source="sample",
+                relationship_name="has-characteristic-value",
+                reverse_relationship_name="value-of",
+                target="characteristic-value",
+                min=0,
+                min_for_each_source=0,
+            ),
         ],
     ),
     NodeValidation(
         node_type="sample-run",
         min=0,
         validations=[
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="sample-run",
                 node_property_name="sample_ref",
-                contraints=PropertyConstraint(required=True),
+                required=False,
+                target_ref_types=["sample"],
             ),
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="sample-run",
                 node_property_name="raw_data_file_refs",
-                contraints=PropertyConstraint(required=True, min_length=1),
+                required=False,
+                target_ref_types=["raw-data-file"],
             ),
         ],
         relationships=[
@@ -892,11 +919,12 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
         node_type="sample-run-configuration",
         min=0,
         validations=[
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="sample-run-configuration",
                 node_property_name="protocol_ref",
-                contraints=PropertyConstraint(required=True),
-            )
+                required=True,
+                target_ref_types=["protocol"],
+            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -914,17 +942,11 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
         min=1,
         max=1,
         validations=[
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="study",
                 node_property_name="created_by_ref",
-                contraints=PropertyConstraint(required=True),
-            ),
-            CvTermValidation(
-                node_type="study",
-                node_property_name="additional_identifiers",
-                validation=AllowAnyCvTerm(
-                    allowed_other_sources=["wikidata", "ILX"],
-                ),
+                required=True,
+                target_ref_types=["data-provider"],
             ),
             NodePropertyValidation(
                 node_type="study",
@@ -969,7 +991,8 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="provides",
                 target="data-provider",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
             ),
             RelationshipValidation(
                 source="study",
@@ -979,14 +1002,6 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 min=0,
                 min_for_each_source=0,
             ),
-            RelationshipValidation(
-                source="study",
-                relationship_name="has-characteristic-definition",
-                reverse_relationship_name="used-in",
-                target="characteristic-definition",
-                min=0,
-                min_for_each_source=0,
-            ),
             RelationshipValidation(
                 source="study",
                 relationship_name="funded-by",
@@ -997,11 +1012,11 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
             ),
             RelationshipValidation(
                 source="study",
-                relationship_name="defines",
-                reverse_relationship_name="defined-in",
-                target="characteristic-type",
-                min=0,
-                min_for_each_source=0,
+                relationship_name="has-characteristic-definition",
+                reverse_relationship_name="used-in",
+                target="characteristic-definition",
+                min=1,
+                min_for_each_source=1,
             ),
             RelationshipValidation(
                 source="study",
@@ -1221,7 +1236,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="value-of",
                 target="characteristic-value",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
             RelationshipValidation(
                 source="subject",
@@ -1298,6 +1313,11 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
         node_type="characteristic-type",
         min=1,
         validations=[
+            NodePropertyValidation(
+                node_type="characteristic-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="characteristic-type",
                 validation=AllowedCvTerms(
@@ -1307,8 +1327,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Characteristic Type",
                         relationship_name="[embedded].characteristic_type_ref",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref",
                     )
                 ],
             ),
@@ -1318,18 +1338,9 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                 source="characteristic-type",
                 relationship_name="type-of",
                 reverse_relationship_name="has-type",
-                target="characteristic-value",
+                target="characteristic-definition",
                 min=0,
-                min_for_each_source=0,
-            ),
-            RelationshipValidation(
-                source="characteristic-type",
-                relationship_name="defined-in",
-                reverse_relationship_name="defines",
-                target="study",
-                min=1,
                 min_for_each_source=1,
-                max_for_each_source=1,
             ),
         ],
     ),
@@ -1347,6 +1358,7 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
             ),
             CvTermValidation(
                 node_type="characteristic-value",
+                min_count=1,
                 validation=AllowAnyCvTerm(
                     allowed_placeholder_values=[CvTermPlaceholder()],
                     allowed_other_sources=["wikidata", "ILX"],
@@ -1355,9 +1367,9 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Organism",
                         relationship_name="has-instance",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref.accession",
-                        source_node_value="NCIT:C14250",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref.accession",
+                        expression_value="NCIT:C14250",
                     )
                 ],
             ),
@@ -1389,9 +1401,9 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
             ),
             RelationshipValidation(
                 source="characteristic-value",
-                relationship_name="has-type",
-                reverse_relationship_name="type-of",
-                target="characteristic-type",
+                relationship_name="value-of",
+                reverse_relationship_name="has-characteristic-value",
+                target="sample",
                 min=0,
                 min_for_each_source=0,
             ),
@@ -1420,8 +1432,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Data Provider",
                         relationship_name="[embedded].created_by_ref",
-                        source_node_type=None,
-                        source_node_property="created_by_ref",
+                        start_node_type=None,
+                        expression="created_by_ref",
                     )
                 ],
             ),
@@ -1460,8 +1472,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="File Format",
                         relationship_name="[embedded].format_ref",
-                        source_node_type=None,
-                        source_node_property="format_ref",
+                        start_node_type=None,
+                        expression="format_ref",
                     )
                 ],
             ),
@@ -1483,8 +1495,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="File Format",
                         relationship_name="[embedded].compression_format_ref",
-                        source_node_type=None,
-                        source_node_property="compression_format_ref",
+                        start_node_type=None,
+                        expression="compression_format_ref",
                     )
                 ],
             ),
@@ -1495,8 +1507,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Analysis Type",
                         relationship_name="[embedded].assay_type_ref",
-                        source_node_type="assay",
-                        source_node_property="assay_type_ref",
+                        start_node_type="assay",
+                        expression="assay_type_ref",
                     )
                 ],
             ),
@@ -1509,8 +1521,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Measurement Type",
                         relationship_name="[embedded].measurement_type_ref",
-                        source_node_type="assay",
-                        source_node_property="measurement_type_ref",
+                        start_node_type="assay",
+                        expression="measurement_type_ref",
                     )
                 ],
             ),
@@ -1522,9 +1534,9 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                 condition=[
                     FilterCondition(
                         name="Technology Type",
-                        relationship_name="[embedded].measurement_type_ref",
-                        source_node_type="assay",
-                        source_node_property="technology_type_ref",
+                        relationship_name="[embedded].technology_type_ref",
+                        start_node_type="assay",
+                        expression="technology_type_ref",
                     )
                 ],
             ),
@@ -1535,22 +1547,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Omics Type",
                         relationship_name="[embedded].omics_type_ref",
-                        source_node_type="assay",
-                        source_node_property="omics_type_ref",
-                    )
-                ],
-            ),
-            CvTermValidation(
-                node_type="descriptor",
-                validation=AllowAnyCvTerm(
-                    allowed_other_sources=["wikidata", "ILX"],
-                    allowed_placeholder_values=[CvTermPlaceholder()],
-                ),
-                condition=[
-                    FilterCondition(
-                        name="Keyword",
-                        relationship_name="has-submitter-keyword",
-                        source_node_type="study",
+                        start_node_type="assay",
+                        expression="omics_type_ref",
                     )
                 ],
             ),
@@ -1730,19 +1728,10 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
         node_type="factor-type",
         min=0,
         validations=[
-            CvTermValidation(
+            NodePropertyValidation(
                 node_type="factor-type",
-                validation=AllowedCvTerms(
-                    cv_terms=list(COMMON_STUDY_FACTOR_DEFINITIONS.values())
-                ),
-                condition=[
-                    FilterCondition(
-                        name="Factor Type",
-                        relationship_name="[embedded].factor_type_ref",
-                        source_node_type="factor-definition",
-                        source_node_property="factor_type_ref",
-                    )
-                ],
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
             ),
         ],
         relationships=[
@@ -1750,9 +1739,9 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                 source="factor-type",
                 relationship_name="type-of",
                 reverse_relationship_name="has-type",
-                target="factor-value",
+                target="factor-definition",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -1763,34 +1752,13 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
         validations=[
             CvTermValidation(
                 node_type="factor-value",
-                validation=AllowAnyCvTerm(allowed_other_sources=["wikidata", "ILX"]),
-            ),
-            CvTermValidation(
-                node_type="factor-value",
-                validation=AllowedCvList(
-                    source_names=["DOID", "HP", "MP", "SNOMED"],
+                validation=AllowAnyCvTerm(
                     allowed_other_sources=["wikidata", "ILX"],
+                    allowed_placeholder_values=[CvTermPlaceholder()],
                 ),
-                condition=[
-                    FilterCondition(
-                        name="Disease",
-                        relationship_name="has-instance",
-                        source_node_type="factor-definition",
-                        source_node_property="factor_type_ref.accession",
-                        source_node_value="EFO:0000408",
-                    )
-                ],
             ),
         ],
         relationships=[
-            RelationshipValidation(
-                source="factor-value",
-                relationship_name="has-type",
-                reverse_relationship_name="type-of",
-                target="factor-type",
-                min=0,
-                min_for_each_source=1,
-            ),
             RelationshipValidation(
                 source="factor-value",
                 relationship_name="instance-of",
@@ -1807,6 +1775,14 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                 min=0,
                 min_for_each_source=1,
             ),
+            RelationshipValidation(
+                source="factor-value",
+                relationship_name="value-of",
+                reverse_relationship_name="has-factor-value",
+                target="specimen",
+                min=0,
+                min_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="factor-value",
                 relationship_name="value-of",
@@ -1839,7 +1815,7 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Reported Metabolite Identifier",
                         relationship_name="identified-as",
-                        source_node_type="metabolite",
+                        start_node_type="metabolite",
                     )
                 ],
             ),
@@ -1859,52 +1835,27 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
         node_type="parameter-type",
         min=0,
         validations=[
+            NodePropertyValidation(
+                node_type="parameter-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="parameter-type",
-                validation=AllowedCvTerms(
-                    cv_terms=list(COMMON_PARAMETER_DEFINITIONS.values()),
+                validation=AllowAnyCvTerm(
                     allowed_other_sources=["wikidata", "ILX"],
+                    allowed_placeholder_values=[CvTermPlaceholder()],
                 ),
             ),
-            CvTermValidation(
-                node_type="parameter-type",
-                validation=AllowedCvTerms(
-                    cv_terms=list(COMMON_PROTOCOL_PARAMETERS["CHMO:0000470"].values())
-                ),
-                condition=[
-                    FilterCondition(
-                        name="Mass spectrometry protocol",
-                        relationship_name="[embedded].parameter_type_ref",
-                        source_node_type="parameter-definition",
-                        source_node_property="[defined-in].protocol_type_ref.accession",
-                        source_node_value="CHMO:0000470",
-                    ),
-                ],
-            ),
-            CvTermValidation(
-                node_type="parameter-type",
-                validation=AllowedCvTerms(
-                    cv_terms=list(COMMON_PROTOCOL_PARAMETERS["CHMO:0001000"].values())
-                ),
-                condition=[
-                    FilterCondition(
-                        name="Chromatography protocol",
-                        relationship_name="[embedded].parameter_definition_refs.parameter_type_ref",
-                        source_node_type="protocol",
-                        source_node_property="protocol_type_ref.accession",
-                        source_node_value="CHMO:0001000",
-                    )
-                ],
-            ),
         ],
         relationships=[
             RelationshipValidation(
                 source="parameter-type",
                 relationship_name="type-of",
                 reverse_relationship_name="has-type",
-                target="parameter-value",
+                target="parameter-definition",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -1920,22 +1871,6 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     allowed_other_sources=["wikidata", "ILX"],
                 ),
             ),
-            CvTermValidation(
-                node_type="parameter-value",
-                validation=AllowAnyCvTerm(
-                    allowed_placeholder_values=[CvTermPlaceholder()],
-                    allowed_other_sources=["wikidata", "ILX"],
-                ),
-                condition=[
-                    FilterCondition(
-                        name="Mass spectrometry instrument",
-                        relationship_name="has-instance",
-                        source_node_type="parameter-definition",
-                        source_node_property="parameter_type_ref.accession",
-                        source_node_value="MSIO:0000171",
-                    )
-                ],
-            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -1945,21 +1880,18 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                 target="parameter-definition",
                 min=0,
                 min_for_each_source=1,
-            ),
-            RelationshipValidation(
-                source="parameter-value",
-                relationship_name="has-type",
-                reverse_relationship_name="type-of",
-                target="parameter-type",
-                min=0,
-                min_for_each_source=1,
-            ),
+            )
         ],
     ),
     CvNodeValidation(
         node_type="protocol-type",
         min=0,
         validations=[
+            NodePropertyValidation(
+                node_type="protocol-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="protocol-type",
                 validation=AllowedCvTerms(
@@ -1970,8 +1902,8 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Protocol Type",
                         relationship_name="[embedded].protocol_type_ref",
-                        source_node_type="protocol",
-                        source_node_property="protocol_type_ref",
+                        start_node_type="protocol",
+                        expression="protocol_type_ref",
                     )
                 ],
             ),
