@@ -1,3 +1,4 @@
+from mhd_model.model import MHD_MODEL_V0_1_MS_PROFILE_NAME
 from mhd_model.model.v0_1.dataset.validation.profile.base import (
     EmbeddedRefValidation,
     RelationshipValidation,
@@ -32,7 +33,7 @@ from mhd_model.shared.validation.definitions import (
     ParentCvTerm,
 )
 
-MHD_MS_PROFILE_V0_1 = MhDatasetValidation()
+MHD_MS_PROFILE_V0_1 = MhDatasetValidation(schema=MHD_MODEL_V0_1_MS_PROFILE_NAME)
 
 MHD_MS_PROFILE_V0_1.mhd_nodes = [
     NodeValidation(
@@ -120,7 +121,7 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="used-in",
                 target="protocol",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -149,6 +150,15 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 min=2,
                 min_for_each_source=0,
             ),
+            RelationshipValidation(
+                source="characteristic-definition",
+                relationship_name="has-type",
+                reverse_relationship_name="type-of",
+                target="characteristic-type",
+                min=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="characteristic-definition",
                 relationship_name="used-in",
@@ -222,6 +232,15 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
             ),
         ],
         relationships=[
+            RelationshipValidation(
+                source="factor-definition",
+                relationship_name="has-type",
+                reverse_relationship_name="type-of",
+                target="factor-type",
+                min=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="factor-definition",
                 relationship_name="has-instance",
@@ -236,7 +255,7 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="has-factor-definition",
                 target="study",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -443,13 +462,22 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 min=1,
                 min_for_each_source=0,
             ),
+            RelationshipValidation(
+                source="parameter-definition",
+                relationship_name="has-type",
+                reverse_relationship_name="type-of",
+                target="parameter-type",
+                min=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="parameter-definition",
                 relationship_name="defined-in",
                 reverse_relationship_name="has-parameter-definition",
                 target="protocol",
                 min=1,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -669,7 +697,7 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 node_type="publication",
                 node_property_name="title",
                 contraints=PropertyConstraint(required=True),
-            )
+            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -709,7 +737,7 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
     ),
     NodeValidation(
         node_type="raw-data-file",
-        min=1,
+        min=0,
         validations=[
             NodePropertyValidation(
                 node_type="raw-data-file",
@@ -723,8 +751,8 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
             ),
             NodePropertyValidation(
                 node_type="raw-data-file",
-                node_property_name="format_ref",
-                contraints=PropertyConstraint(required=True),
+                node_property_name="extension",
+                contraints=PropertyConstraint(required=True, min_length=2),
             ),
         ],
         relationships=[
@@ -741,9 +769,8 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 relationship_name="created-in",
                 reverse_relationship_name="has-raw-data-file",
                 target="study",
-                min=1,
+                min=0,
                 min_for_each_source=1,
-                max_for_each_source=1,
             ),
             RelationshipValidation(
                 source="raw-data-file",
@@ -771,8 +798,8 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
             ),
             NodePropertyValidation(
                 node_type="result-file",
-                node_property_name="format_ref",
-                contraints=PropertyConstraint(required=True),
+                node_property_name="extension",
+                contraints=PropertyConstraint(required=True, min_length=2),
             ),
         ],
         relationships=[
@@ -859,21 +886,31 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 min=0,
                 min_for_each_source=0,
             ),
+            RelationshipValidation(
+                source="sample",
+                relationship_name="has-characteristic-value",
+                reverse_relationship_name="value-of",
+                target="characteristic-value",
+                min=0,
+                min_for_each_source=0,
+            ),
         ],
     ),
     NodeValidation(
         node_type="sample-run",
         min=1,
         validations=[
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="sample-run",
                 node_property_name="sample_ref",
-                contraints=PropertyConstraint(required=True),
+                required=True,
+                target_ref_types=["sample"],
             ),
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="sample-run",
                 node_property_name="raw_data_file_refs",
-                contraints=PropertyConstraint(required=True, min_length=1),
+                required=True,
+                target_ref_types=["raw-data-file"],
             ),
         ],
         relationships=[
@@ -891,11 +928,12 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
         node_type="sample-run-configuration",
         min=0,
         validations=[
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="sample-run-configuration",
                 node_property_name="protocol_ref",
-                contraints=PropertyConstraint(required=True),
-            )
+                required=True,
+                target_ref_types=["protocol"],
+            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -911,11 +949,13 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
     NodeValidation(
         node_type="study",
         min=1,
+        max=1,
         validations=[
-            NodePropertyValidation(
+            EmbeddedRefValidation(
                 node_type="study",
                 node_property_name="created_by_ref",
-                contraints=PropertyConstraint(required=True),
+                required=True,
+                target_ref_types=["data-provider"],
             ),
             CvTermValidation(
                 node_type="study",
@@ -929,6 +969,11 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 node_property_name="mhd_identifier",
                 contraints=PropertyConstraint(required=True, min_length=8),
             ),
+            NodePropertyValidation(
+                node_type="study",
+                node_property_name="repository_identifier",
+                contraints=PropertyConstraint(required=True, min_length=2),
+            ),
             NodePropertyValidation(
                 node_type="study",
                 node_property_name="title",
@@ -951,14 +996,20 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
             ),
             NodePropertyValidation(
                 node_type="study",
-                node_property_name="license",
+                node_property_name="dataset_url_list",
                 contraints=PropertyConstraint(required=True),
             ),
             NodePropertyValidation(
                 node_type="study",
-                node_property_name="protocol_refs",
+                node_property_name="license",
                 contraints=PropertyConstraint(required=True),
             ),
+            EmbeddedRefValidation(
+                node_type="study",
+                node_property_name="protocol_refs",
+                required=True,
+                target_ref_types=["protocol"],
+            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -967,7 +1018,8 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="provides",
                 target="data-provider",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
+                max_for_each_source=1,
             ),
             RelationshipValidation(
                 source="study",
@@ -993,14 +1045,6 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 min=2,
                 min_for_each_source=2,
             ),
-            RelationshipValidation(
-                source="study",
-                relationship_name="defines",
-                reverse_relationship_name="defined-in",
-                target="characteristic-type",
-                min=2,
-                min_for_each_source=2,
-            ),
             RelationshipValidation(
                 source="study",
                 relationship_name="has-derived-data-file",
@@ -1110,8 +1154,8 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 relationship_name="has-raw-data-file",
                 reverse_relationship_name="created-in",
                 target="raw-data-file",
-                min=1,
-                min_for_each_source=1,
+                min=0,
+                min_for_each_source=0,
             ),
             RelationshipValidation(
                 source="study",
@@ -1219,7 +1263,7 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 reverse_relationship_name="value-of",
                 target="characteristic-value",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
             RelationshipValidation(
                 source="subject",
@@ -1261,11 +1305,6 @@ MHD_MS_PROFILE_V0_1.mhd_nodes = [
                 node_property_name="name",
                 contraints=PropertyConstraint(required=True, min_length=2),
             ),
-            NodePropertyValidation(
-                node_type="supplementary-file",
-                node_property_name="format_ref",
-                contraints=PropertyConstraint(required=True),
-            ),
         ],
         relationships=[
             RelationshipValidation(
@@ -1301,8 +1340,14 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
         node_type="characteristic-type",
         min=2,
         validations=[
+            NodePropertyValidation(
+                node_type="characteristic-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="characteristic-type",
+                min_count=1,
                 validation=AllowedCvTerms(
                     cv_terms=list(COMMON_CHARACTERISTIC_DEFINITIONS.values())
                 ),
@@ -1310,8 +1355,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Characteristic Type",
                         relationship_name="[embedded].characteristic_type_ref",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref",
                     )
                 ],
             ),
@@ -1321,18 +1366,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 source="characteristic-type",
                 relationship_name="type-of",
                 reverse_relationship_name="has-type",
-                target="characteristic-value",
-                min=2,
-                min_for_each_source=0,
-            ),
-            RelationshipValidation(
-                source="characteristic-type",
-                relationship_name="defined-in",
-                reverse_relationship_name="defines",
-                target="study",
+                target="characteristic-definition",
                 min=2,
                 min_for_each_source=1,
-                max_for_each_source=1,
             ),
         ],
     ),
@@ -1350,6 +1386,7 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
             ),
             CvTermValidation(
                 node_type="characteristic-value",
+                min_count=1,
                 validation=AllowedCvList(
                     source_names=["ENVO", "NCBITAXON"],
                     allowed_other_sources=["wikidata", "ILX"],
@@ -1358,14 +1395,15 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Organism",
                         relationship_name="has-instance",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref.accession",
-                        source_node_value="NCIT:C14250",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref.accession",
+                        expression_value="NCIT:C14250",
                     )
                 ],
             ),
             CvTermValidation(
                 node_type="characteristic-value",
+                min_count=1,
                 validation=AllowedCvList(
                     source_names=["UBERON", "BTO", "NCIT", "SNOMED", "MSIO"],
                     allowed_other_sources=["wikidata", "ILX"],
@@ -1374,14 +1412,15 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Organism part",
                         relationship_name="has-instance",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref.accession",
-                        source_node_value="NCIT:C103199",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref.accession",
+                        expression_value="NCIT:C103199",
                     )
                 ],
             ),
             CvTermValidation(
                 node_type="characteristic-value",
+                min_count=1,
                 validation=AllowedCvList(
                     source_names=["DOID", "HP", "MP", "SNOMED"],
                     allowed_other_sources=["wikidata", "ILX"],
@@ -1390,14 +1429,15 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Disease",
                         relationship_name="has-instance",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref.accession",
-                        source_node_value="EFO:0000408",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref.accession",
+                        expression_value="EFO:0000408",
                     )
                 ],
             ),
             CvTermValidation(
                 node_type="characteristic-value",
+                min_count=1,
                 validation=AllowedCvList(
                     source_names=["CL", "CLO"],
                     allowed_other_sources=["wikidata", "ILX"],
@@ -1413,9 +1453,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Cell type",
                         relationship_name="has-instance",
-                        source_node_type="characteristic-definition",
-                        source_node_property="characteristic_type_ref.accession",
-                        source_node_value="EFO:0000324",
+                        start_node_type="characteristic-definition",
+                        expression="characteristic_type_ref.accession",
+                        expression_value="EFO:0000324",
                     )
                 ],
             ),
@@ -1445,9 +1485,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
             #         FilterCondition(
             #             name="Geographic location - Country",
             #             relationship_name="has-instance",
-            #             source_node_type="characteristic-definition",
-            #             source_node_property="characteristic_type_ref.accession",
-            #             source_node_value="GAZ:00000448",
+            #             start_node_type="characteristic-definition",
+            #             expression="characteristic_type_ref.accession",
+            #             expression_value="GAZ:00000448",
             #         )
             #     ],
             # ),
@@ -1467,7 +1507,7 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 reverse_relationship_name="has-characteristic-value",
                 target="subject",
                 min=0,
-                min_for_each_source=1,
+                min_for_each_source=0,
             ),
             RelationshipValidation(
                 source="characteristic-value",
@@ -1479,9 +1519,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
             ),
             RelationshipValidation(
                 source="characteristic-value",
-                relationship_name="has-type",
-                reverse_relationship_name="type-of",
-                target="characteristic-type",
+                relationship_name="value-of",
+                reverse_relationship_name="has-characteristic-value",
+                target="sample",
                 min=0,
                 min_for_each_source=0,
             ),
@@ -1510,8 +1550,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Data Provider",
                         relationship_name="[embedded].created_by_ref",
-                        source_node_type=None,
-                        source_node_property="created_by_ref",
+                        start_node_type=None,
+                        expression="created_by_ref",
                     )
                 ],
             ),
@@ -1550,8 +1590,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="File Format",
                         relationship_name="[embedded].format_ref",
-                        source_node_type=None,
-                        source_node_property="format_ref",
+                        start_node_type=None,
+                        expression="format_ref",
                     )
                 ],
             ),
@@ -1573,8 +1613,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="File Format",
                         relationship_name="[embedded].compression_format_ref",
-                        source_node_type=None,
-                        source_node_property="compression_format_ref",
+                        start_node_type=None,
+                        expression="compression_format_ref",
                     )
                 ],
             ),
@@ -1585,8 +1625,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Analysis Type",
                         relationship_name="[embedded].assay_type_ref",
-                        source_node_type="assay",
-                        source_node_property="assay_type_ref",
+                        start_node_type="assay",
+                        expression="assay_type_ref",
                     )
                 ],
             ),
@@ -1599,8 +1639,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Measurement Type",
                         relationship_name="[embedded].measurement_type_ref",
-                        source_node_type="assay",
-                        source_node_property="measurement_type_ref",
+                        start_node_type="assay",
+                        expression="measurement_type_ref",
                     )
                 ],
             ),
@@ -1612,9 +1652,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 condition=[
                     FilterCondition(
                         name="Technology Type",
-                        relationship_name="[embedded].measurement_type_ref",
-                        source_node_type="assay",
-                        source_node_property="technology_type_ref",
+                        relationship_name="[embedded].technology_type_ref",
+                        start_node_type="assay",
+                        expression="technology_type_ref",
                     )
                 ],
             ),
@@ -1625,8 +1665,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Omics Type",
                         relationship_name="[embedded].omics_type_ref",
-                        source_node_type="assay",
-                        source_node_property="omics_type_ref",
+                        start_node_type="assay",
+                        expression="omics_type_ref",
                     )
                 ],
             ),
@@ -1640,7 +1680,7 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Keyword",
                         relationship_name="has-submitter-keyword",
-                        source_node_type="study",
+                        start_node_type="study",
                     )
                 ],
             ),
@@ -1820,6 +1860,11 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
         node_type="factor-type",
         min=0,
         validations=[
+            NodePropertyValidation(
+                node_type="factor-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="factor-type",
                 validation=AllowedCvTerms(
@@ -1829,8 +1874,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Factor Type",
                         relationship_name="[embedded].factor_type_ref",
-                        source_node_type="factor-definition",
-                        source_node_property="factor_type_ref",
+                        start_node_type="factor-definition",
+                        expression="factor_type_ref",
                     )
                 ],
             ),
@@ -1840,9 +1885,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 source="factor-type",
                 relationship_name="type-of",
                 reverse_relationship_name="has-type",
-                target="factor-value",
+                target="factor-definition",
                 min=0,
-                min_for_each_source=0,
+                min_for_each_source=1,
             ),
         ],
     ),
@@ -1853,7 +1898,10 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
         validations=[
             CvTermValidation(
                 node_type="factor-value",
-                validation=AllowAnyCvTerm(allowed_other_sources=["wikidata", "ILX"]),
+                validation=AllowAnyCvTerm(
+                    allowed_other_sources=["wikidata", "ILX"],
+                    allowed_placeholder_values=[CvTermPlaceholder()],
+                ),
             ),
             CvTermValidation(
                 node_type="factor-value",
@@ -1865,22 +1913,14 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Disease",
                         relationship_name="has-instance",
-                        source_node_type="factor-definition",
-                        source_node_property="factor_type_ref.accession",
-                        source_node_value="EFO:0000408",
+                        start_node_type="factor-definition",
+                        expression="factor_type_ref.accession",
+                        expression_value="EFO:0000408",
                     )
                 ],
             ),
         ],
         relationships=[
-            RelationshipValidation(
-                source="factor-value",
-                relationship_name="has-type",
-                reverse_relationship_name="type-of",
-                target="factor-type",
-                min=0,
-                min_for_each_source=1,
-            ),
             RelationshipValidation(
                 source="factor-value",
                 relationship_name="instance-of",
@@ -1897,6 +1937,14 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 min=0,
                 min_for_each_source=1,
             ),
+            RelationshipValidation(
+                source="factor-value",
+                relationship_name="value-of",
+                reverse_relationship_name="has-factor-value",
+                target="specimen",
+                min=0,
+                min_for_each_source=1,
+            ),
             RelationshipValidation(
                 source="factor-value",
                 relationship_name="value-of",
@@ -1929,7 +1977,7 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Reported Metabolite Identifier",
                         relationship_name="identified-as",
-                        source_node_type="metabolite",
+                        start_node_type="metabolite",
                     )
                 ],
             ),
@@ -1949,6 +1997,11 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
         node_type="parameter-type",
         min=1,
         validations=[
+            NodePropertyValidation(
+                node_type="parameter-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="parameter-type",
                 validation=AllowedCvTerms(
@@ -1958,6 +2011,7 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
             ),
             CvTermValidation(
                 node_type="parameter-type",
+                min_count=1,
                 validation=AllowedCvTerms(
                     cv_terms=list(COMMON_PROTOCOL_PARAMETERS["CHMO:0000470"].values())
                 ),
@@ -1965,9 +2019,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Mass spectrometry protocol",
                         relationship_name="[embedded].parameter_type_ref",
-                        source_node_type="parameter-definition",
-                        source_node_property="[defined-in].protocol_type_ref.accession",
-                        source_node_value="CHMO:0000470",
+                        start_node_type="parameter-definition",
+                        expression="[defined-in].protocol_type_ref.accession",
+                        expression_value="CHMO:0000470",
                     ),
                 ],
             ),
@@ -1980,9 +2034,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Chromatography protocol",
                         relationship_name="[embedded].parameter_definition_refs.parameter_type_ref",
-                        source_node_type="protocol",
-                        source_node_property="protocol_type_ref.accession",
-                        source_node_value="CHMO:0001000",
+                        start_node_type="protocol",
+                        expression="protocol_type_ref.accession",
+                        expression_value="CHMO:0001000",
                     )
                 ],
             ),
@@ -1992,14 +2046,6 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 source="parameter-type",
                 relationship_name="type-of",
                 reverse_relationship_name="has-type",
-                target="parameter-value",
-                min=0,
-                min_for_each_source=1,
-            ),
-            RelationshipValidation(
-                source="parameter-type",
-                relationship_name="has-instance",
-                reverse_relationship_name="instance-of",
                 target="parameter-definition",
                 min=0,
                 min_for_each_source=1,
@@ -2020,6 +2066,7 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
             ),
             CvTermValidation(
                 node_type="parameter-value",
+                min_count=1,
                 validation=AllowedChildrenCvTerms(
                     parent_cv_terms=[
                         ParentCvTerm(
@@ -2048,9 +2095,9 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Mass spectrometry instrument",
                         relationship_name="has-instance",
-                        source_node_type="parameter-definition",
-                        source_node_property="parameter_type_ref.accession",
-                        source_node_value="MSIO:0000171",
+                        start_node_type="parameter-definition",
+                        expression="parameter_type_ref.accession",
+                        expression_value="MSIO:0000171",
                     )
                 ],
             ),
@@ -2064,22 +2111,20 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                 min=1,
                 min_for_each_source=1,
             ),
-            RelationshipValidation(
-                source="parameter-value",
-                relationship_name="has-type",
-                reverse_relationship_name="type-of",
-                target="parameter-type",
-                min=1,
-                min_for_each_source=1,
-            ),
         ],
     ),
     CvNodeValidation(
         node_type="protocol-type",
         min=1,
         validations=[
+            NodePropertyValidation(
+                node_type="protocol-type",
+                node_property_name="name",
+                contraints=PropertyConstraint(required=True),
+            ),
             CvTermValidation(
                 node_type="protocol-type",
+                min_count=1,
                 validation=AllowedCvTerms(
                     cv_terms=list(COMMON_PROTOCOLS.values()),
                     allowed_other_sources=["wikidata", "ILX"],
@@ -2088,8 +2133,8 @@ MHD_MS_PROFILE_V0_1.cv_nodes = [
                     FilterCondition(
                         name="Protocol Type",
                         relationship_name="[embedded].protocol_type_ref",
-                        source_node_type="protocol",
-                        source_node_property="protocol_type_ref",
+                        start_node_type="protocol",
+                        expression="protocol_type_ref",
                     )
                 ],
             ),
